function [yp, b, i, bt] = poiReg(x, y, bo, er)
  % Poisson regression
  % x must be: nd X nv+1, i.e. x1, x2, .., xnv 1
  % yp   prediction
  % b    parameters
  % i    number of iterations
  % bt   all b-estimates
  % x,y  data (values from 1) 
  % bo   initial parametrs
  % er   error for interrupting the iterations
  % y=[] only prediction is computed
  
  if ~isempty(y)
    [nd, nv] = size(x);
    if nargin < 3
      bo = ones(nv, 1); 
    end
    if nargin < 4
      er = 0.01;
    end
    if nd < nv
      yp = 0; 
      b = bo; 
      i = [];
      return
    end
    b = bo;
    bt = b;
    for i = 1:1000
      ex = exp(x * b);
      d1 = sum(x' * diag(y - ex), 2);    % 1st derivative
      d2 = x' * diag(ex) * x;           % 2nd derivative
      b = b + inv(d2 + 1e-6 * eye(size(d2))) * d1;  % Newton
      d = sqrt((b - bo)' * (b - bo));
      if d < er, break, end
      bo = b;
      bt = [bt, b];
    end
  else
    b = bo;
    i = 0;
    bt = [];
  end
  yp = exp(x * b);  % prediction with the mean value
end
